<?php
session_start();

// Verifica che l'utente sia autenticato
if (!isset($_SESSION['username'])) {
    header('Location: register.php');
    exit;
}

// Nome file per salvare l'elenco delle stanze
$roomsFile = 'rooms.txt';

// Verifica che una stanza sia stata selezionata
if (!isset($_SESSION['currentRoom'])) {
    header('Location: create_room.php');
    exit;
}

// Cambia la stanza corrente
if (isset($_POST['selectRoom'])) {
    $selectedRoom = htmlspecialchars($_POST['selectRoom']);
    $_SESSION['currentRoom'] = $selectedRoom;
    header('Location: chat.php');
    exit;
}

// Nome del file per la stanza corrente
$currentRoom = $_SESSION['currentRoom'];
$currentRoomFile = "rooms/$currentRoom.txt";

// Gestione invio messaggi
if (isset($_POST['message']) && !empty(trim($_POST['message']))) {
    $message = htmlspecialchars(trim($_POST['message']));
    $username = $_SESSION['username'];
    $time = date('H:i');

    // Salva il messaggio nel file della stanza
    $log = "[$time] $username: $message" . PHP_EOL;
    file_put_contents($currentRoomFile, $log, FILE_APPEND | LOCK_EX);
}

// Restituisce i messaggi se richiesto
if (isset($_GET['action']) && $_GET['action'] === 'getMessages') {
    if (file_exists($currentRoomFile)) {
        echo nl2br(file_get_contents($currentRoomFile));
    }
    exit;
}

// Elenco delle stanze
$rooms = file_exists($roomsFile) ? file($roomsFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
?>
<!DOCTYPE html>
<html>
<head>
    <title>Chat - <?php echo htmlspecialchars($currentRoom); ?></title>
    <script>
        function updateMessages() {
            fetch('chat.php?action=getMessages')
                .then(response => response.text())
                .then(data => {
                    const chatbox = document.getElementById('chatbox');
                    chatbox.innerHTML = data;
                    chatbox.scrollTop = chatbox.scrollHeight;
                })
                .catch(error => console.error('Errore nel caricamento dei messaggi:', error));
        }

        function sendMessage(event) {
            event.preventDefault();
            const messageInput = document.getElementById('message');
            const message = messageInput.value.trim();

            if (message) {
                fetch('chat.php', {
                    method: 'POST',
                    headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                    body: `message=${encodeURIComponent(message)}`,
                })
                .then(() => {
                    messageInput.value = '';
                    updateMessages();
                })
                .catch(error => console.error('Errore nell\'invio del messaggio:', error));
            }
        }

        setInterval(updateMessages, 2000);
        window.onload = updateMessages;
    </script>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
            text-align: center;
        }

        #chatbox {
            width: 80%;
            margin: 0 auto;
            border: 1px solid #ccc;
            padding: 10px;
            height: 300px;
            overflow-y: scroll;
            background-color: #f9f9f9;
            text-align: left;
        }

        form {
            margin-top: 10px;
        }

        input[type="text"] {
            width: 70%;
            padding: 10px;
            margin-right: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
        }

        select {
            padding: 10px;
            width: 220px;
            margin-bottom: 10px;
            border: 1px solid #ccc;
            border-radius: 5px;
        }

        button {
            padding: 10px 20px;
            background-color: #28a745;
            color: white;
            border: none;
            border-radius: 5px;
            cursor: pointer;
        }

        button:hover {
            background-color: #218838;
        }

        .logout {
            background-color: #dc3545;
            color: white;
            margin-top: 20px;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            cursor: pointer;
        }

        .logout:hover {
            background-color: #c82333;
        }
    </style>
</head>
<body>
    <h1>Chat - Stanza: <?php echo htmlspecialchars($currentRoom); ?></h1>
    <p><strong>Benvenuto, <?php echo $_SESSION['username']; ?>!</strong></p>
    <form method="POST">
        <label for="selectRoom">Cambia Stanza:</label>
        <select id="selectRoom" name="selectRoom" onchange="this.form.submit()">
            <?php foreach ($rooms as $room): ?>
                <option value="<?php echo htmlspecialchars($room); ?>" <?php echo ($room === $currentRoom) ? 'selected' : ''; ?>>
                    <?php echo htmlspecialchars($room); ?>
                </option>
            <?php endforeach; ?>
        </select>
    </form>
    <div id="chatbox">
        <!-- Messaggi caricati dinamicamente -->
    </div>
    <form onsubmit="sendMessage(event)">
        <input type="text" id="message" placeholder="Scrivi un messaggio..." required>
        <button type="submit">Invia</button>
    </form>
    <form method="POST" action="logout.php">
        <button type="submit" class="logout">Logout</button>
    </form>
</body>
</html>
