<?php
session_start();

// Verifica che l'utente sia autenticato
if (!isset($_SESSION['username'])) {
    header('Location: register.php');
    exit;
}

// Nome file per salvare l'elenco delle stanze
$roomsFile = 'rooms.txt';
$errorMessage = '';
$confirmationMessage = '';
$roomName = '';

// Gestione della creazione di una nuova stanza
if (isset($_POST['newRoom']) && !empty(trim($_POST['newRoom']))) {
    $roomName = htmlspecialchars(trim($_POST['newRoom']));

    // Controlla se la stanza esiste già
    $rooms = file_exists($roomsFile) ? file($roomsFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
    if (in_array($roomName, $rooms)) {
        // Messaggio di conferma per l'uso della stanza esistente
        $confirmationMessage = "La stanza '$roomName' esiste già. Vuoi entrare in questa stanza?";
    } else {
        // Crea la stanza e reindirizza
        file_put_contents($roomsFile, $roomName . PHP_EOL, FILE_APPEND | LOCK_EX);
        mkdir('rooms', 0777, true); // Assicurati che la directory esista
        file_put_contents("rooms/$roomName.txt", "", LOCK_EX); // Crea il file della stanza
        $_SESSION['currentRoom'] = $roomName;
        header('Location: chat.php');
        exit;
    }
}

// Selezione di una stanza esistente
if (isset($_POST['selectRoom']) && !empty($_POST['selectRoom'])) {
    $_SESSION['currentRoom'] = htmlspecialchars($_POST['selectRoom']);
    header('Location: chat.php');
    exit;
}

// Elenco delle stanze
$rooms = file_exists($roomsFile) ? file($roomsFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
?>
<!DOCTYPE html>
<html>
<head>
    <title>Creazione Stanze</title>
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
            background-color: #f3f4f6;
        }

        .container {
            text-align: center;
            background: #ffffff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.1);
            width: 300px;
        }

        h1 {
            font-size: 24px;
            color: #333333;
            margin-bottom: 20px;
        }

        input[type="text"], select {
            padding: 12px;
            width: 100%;
            margin-bottom: 20px;
            border: 1px solid #d1d5db;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 14px;
        }

        .error, .confirmation {
            color: #dc3545;
            margin-bottom: 15px;
        }

        .confirmation {
            color: #007bff;
        }

        .button-container {
            display: flex;
            justify-content: space-between;
            gap: 10px;
        }

        button {
            padding: 12px;
            font-size: 14px;
            font-weight: bold;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            flex: 1;
        }

        button.create {
            background-color: #28a745;
            color: white;
        }

        button.create:hover {
            background-color: #218838;
        }

        button.enter {
            background-color: #007bff;
            color: white;
        }

        button.enter:hover {
            background-color: #0056b3;
        }

        @media (max-width: 400px) {
            .container {
                width: 90%;
            }

            .button-container {
                flex-direction: column;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Crea o Entra in una Stanza</h1>
        <?php if (!empty($confirmationMessage)): ?>
            <div class="confirmation"><?php echo $confirmationMessage; ?></div>
            <form method="POST">
                <input type="hidden" name="confirmRoom" value="<?php echo htmlspecialchars($roomName); ?>">
                <div class="button-container">
                    <button type="submit" class="enter">Sì, entra</button>
                    <button type="button" class="create" onclick="window.location.href='create_room.php'">No, torna indietro</button>
                </div>
            </form>
        <?php else: ?>
            <form method="POST">
                <label for="newRoom">Inserisci il nome della stanza:</label>
                <input type="text" id="newRoom" name="newRoom" placeholder="Nome della stanza">
                <button type="submit" class="create">Crea Stanza</button>
            </form>
            <hr>
            <h2>Stanze Esistenti</h2>
            <form method="POST">
                <label for="selectRoom">Seleziona una stanza:</label>
                <select id="selectRoom" name="selectRoom">
                    <option value="">-- Seleziona una stanza --</option>
                    <?php foreach ($rooms as $room): ?>
                        <option value="<?php echo htmlspecialchars($room); ?>">
                            <?php echo htmlspecialchars($room); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
                <button type="submit" class="enter">Entra</button>
            </form>
        <?php endif; ?>
    </div>
</body>
</html>
