<?php
session_start();

// Nome del file per salvare gli utenti
$usersFile = 'users.txt';
$errorMessage = '';
$confirmationMessage = '';
$username = '';

// Gestione della registrazione
if (isset($_POST['username']) && !empty(trim($_POST['username']))) {
    $username = htmlspecialchars(trim($_POST['username']));

    // Controlla se l'utente esiste già
    $users = file_exists($usersFile) ? file($usersFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES) : [];
    if (in_array($username, $users)) {
        // Messaggio di conferma per l'uso del nome esistente
        $confirmationMessage = "Il nome utente '$username' è già registrato. Vuoi continuare come '$username'?";
    } else {
        // Salva l'utente e reindirizza
        file_put_contents($usersFile, $username . PHP_EOL, FILE_APPEND | LOCK_EX);
        $_SESSION['username'] = $username;
        header('Location: create_room.php');
        exit;
    }
}

// Conferma dell'uso del nome utente esistente
if (isset($_POST['confirmUsername'])) {
    $_SESSION['username'] = htmlspecialchars($_POST['confirmUsername']);
    header('Location: create_room.php');
    exit;
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Registrazione Utente</title>
    <style>
        body {
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
            display: flex;
            justify-content: center;
            align-items: center;
            height: 100vh;
            margin: 0;
            background-color: #f3f4f6;
        }

        .container {
            text-align: center;
            background: #ffffff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.1);
            width: 300px;
        }

        h1 {
            font-size: 24px;
            color: #333333;
            margin-bottom: 20px;
        }

        input[type="text"] {
            padding: 12px;
            width: 100%;
            margin-bottom: 20px;
            border: 1px solid #d1d5db;
            border-radius: 5px;
            box-sizing: border-box;
            font-size: 14px;
        }

        .error, .confirmation {
            color: #dc3545;
            margin-bottom: 15px;
        }

        .confirmation {
            color: #007bff;
        }

        .button-container {
            display: flex;
            justify-content: space-between;
            gap: 10px;
        }

        button {
            padding: 12px;
            font-size: 14px;
            font-weight: bold;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            flex: 1;
        }

        button.register {
            background-color: #007bff;
            color: white;
        }

        button.register:hover {
            background-color: #0056b3;
        }

        button.logout {
            background-color: #dc3545;
            color: white;
        }

        button.logout:hover {
            background-color: #c82333;
        }

        button.confirm {
            background-color: #28a745;
            color: white;
        }

        button.confirm:hover {
            background-color: #218838;
        }

        @media (max-width: 400px) {
            .container {
                width: 90%;
            }

            .button-container {
                flex-direction: column;
            }
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Registrati</h1>
        <?php if (!empty($confirmationMessage)): ?>
            <div class="confirmation"><?php echo $confirmationMessage; ?></div>
            <form method="POST">
                <input type="hidden" name="confirmUsername" value="<?php echo htmlspecialchars($username); ?>">
                <div class="button-container">
                    <button type="submit" class="confirm">Sì, continua</button>
                    <button type="button" class="register" onclick="window.location.href='register.php'">No, torna indietro</button>
                </div>
            </form>
        <?php else: ?>
            <?php if (!empty($errorMessage)): ?>
                <div class="error"><?php echo $errorMessage; ?></div>
            <?php endif; ?>
            <form method="POST">
                <label for="username">Inserisci il tuo nome utente:</label>
                <input type="text" id="username" name="username" required placeholder="Nome utente">
                <div class="button-container">
                    <button type="submit" class="register">Registrati</button>
                    <button type="button" class="logout" onclick="window.location.href='logout.php'">Logout</button>
                </div>
            </form>
        <?php endif; ?>
    </div>
</body>
</html>
